itwinai Tensorflow Modules
==========================


trainer.py
+++++++++++

.. .. literalinclude:: ../src/itwinai/tensorflow/trainer.py
   :language: python

.. automodule:: itwinai.tensorflow.trainer
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

utils.py
++++++++

.. automodule:: itwinai.tensorflow.utils
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

.. .. literalinclude:: ../src/itwinai/tensorflow/utils.py
   :language: python


distributed.py
++++++++++++++

.. automodule:: itwinai.tensorflow.distributed
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

.. .. literalinclude:: ../src/itwinai/tensorflow/distributed.py
   :language: python
